package data

import (
	"context"

	"github.com/go-kratos/kratos/v2/log"

	"demo/internal/biz"
)

type creativeRepo struct {
	data *Data
	log  *log.Helper
}

func NewCreativeRepo(data *Data, logger log.Logger) biz.CreativeRepo {
	return &creativeRepo{
		data: data,
		log:  log.NewHelper(logger),
	}
}

func (p *creativeRepo) List(ctx context.Context, customerId int64, req *biz.ListReportRequest) (int64, biz.CreativeList, error) {
	tableName := "ads_report_creative_day"
	if req.TimeGranularity == biz.StatTimeGranularityHourly {
		tableName = "ads_report_creative_hour"
	}
	db := p.data.db.Table(tableName).
		Select("creative_id, advertise_id AS ad_id, advertise_name AS ad_name, "+reportCommonFiled).
		Where("customer_id = ?", customerId).
		Where("is_delete = ?", 0)

	// add start_date and end_date condition
	if req.StartDate != "" {
		db = db.Where("date_long >= ?", req.StartDateLong)
	}
	if req.EndDate != "" {
		db = db.Where("date_long <= ?", req.EndDateLong)
	}

	var total int64
	if err := db.Count(&total).Error; err != nil {
		return 0, nil, err
	}
	var list biz.CreativeList
	if err := db.Order(req.GetOrderBy("id") + " " + req.GetOrderByMode()).
		Limit(req.Limit()).Offset(req.Offset()).Scan(&list).Error; err != nil {
		return total, nil, err
	}
	return total, list, nil
}
