package server

import (
	"github.com/gin-gonic/gin"
	"github.com/go-kratos/kratos/v2/log"
	"github.com/go-kratos/kratos/v2/middleware/recovery"
	kratos_http "github.com/go-kratos/kratos/v2/transport/http"

	"demo/internal/conf"
	"demo/internal/router"
)

// NewHTTPServer new an HTTP server.
func NewHTTPServer(c *conf.Server, web *router.Web, logger log.Logger) *kratos_http.Server {
	var opts = []kratos_http.ServerOption{
		kratos_http.Middleware(
			recovery.Recovery(),
			// tracing.Server(),
			// logging.Server(logger),
		),
	}
	if c.Http.Network != "" {
		opts = append(opts, kratos_http.Network(c.Http.Network))
	}
	if c.Http.Addr != "" {
		opts = append(opts, kratos_http.Address(c.Http.Addr))
	}
	if c.Http.Timeout != nil {
		opts = append(opts, kratos_http.Timeout(c.Http.Timeout.AsDuration()))
	}
	srv := kratos_http.NewServer(opts...)
	engine := gin.Default()
	web.RouterInit(engine)
	srv.HandlePrefix("/", engine)
	return srv
}
