package service

import (
	"strconv"

	"github.com/gin-gonic/gin"
	"github.com/go-kratos/kratos/v2/log"

	"demo/internal/biz"
	"demo/internal/biz/errs"
	"demo/internal/util"
)

type ReportService struct {
	uc  *biz.ReportUsecase
	log *log.Helper
}

// NewReportService new a report service.
func NewReportService(uc *biz.ReportUsecase, logger log.Logger) *ReportService {
	return &ReportService{uc: uc, log: log.NewHelper(logger)}
}

// ListCampaignData 查询广告组数据报表
// @tags report
// @Summary 查询广告组数据报表
// @Description 查询广告组数据报表
// @Accept json
// @Produce  json
// @Param req body biz.ListReportRequest true "请求参数"
// @Success 200 {object} biz.Response{data=biz.ListCampaignResponse} "success"
// @Router /report/campaign [POST]
func (p *ReportService) ListCampaignData(ctx *gin.Context) {
	var req biz.ListReportRequest
	if err := ctx.ShouldBind(&req); err != nil {
		p.log.Error("ShouldBind err:", err)
		ResponseError(ctx, errs.ErrorArgs)
		return
	}
	if err := req.Validate(); err != nil {
		p.log.Error("Validate err:", err)
		ResponseError(ctx, err)
		return
	}

	customerIdStr := ctx.GetString(util.CustomerId)
	customerId, err := strconv.Atoi(customerIdStr)
	if err != nil {
		p.log.Error("Atoi err:", err)
		ResponseError(ctx, err)
		return
	}
	data, err := p.uc.ListCampaignData(ctx, int64(customerId), &req)
	if err != nil {
		p.log.Error("ListCampaignData err:", err)
		ResponseError(ctx, err)
		return
	}
	ResponseSuccess(ctx, data)
}

// ListAdData 查询广告计划数据报表
// @tags report
// @Summary 查询广告计划数据报表
// @Description 查询广告计划数据报表
// @Accept json
// @Produce  json
// @Param req body biz.ListReportRequest true "请求参数"
// @Success 200 {object} biz.Response{data=biz.ListAdResponse} "success"
// @Router /report/ad [POST]
func (p *ReportService) ListAdData(ctx *gin.Context) {
	var req biz.ListReportRequest
	if err := ctx.ShouldBind(&req); err != nil {
		p.log.Error("ShouldBind err:", err)
		ResponseError(ctx, errs.ErrorArgs)
		return
	}
	if err := req.Validate(); err != nil {
		p.log.Error("Validate err:", err)
		ResponseError(ctx, err)
		return
	}

	customerIdStr := ctx.GetString(util.CustomerId)
	customerId, err := strconv.Atoi(customerIdStr)
	if err != nil {
		p.log.Error("Atoi err:", err)
		ResponseError(ctx, err)
		return
	}
	data, err := p.uc.ListAdData(ctx, int64(customerId), &req)
	if err != nil {
		p.log.Error("ListAdData err:", err)
		ResponseError(ctx, err)
		return
	}
	ResponseSuccess(ctx, data)
}

// ListCreativeData 查询广告创意数据报表
// @tags report
// @Summary 查询广告创意数据报表
// @Description 查询广告创意数据报表
// @Accept json
// @Produce  json
// @Param req body biz.ListReportRequest true "请求参数"
// @Success 200 {object} biz.Response{data=biz.ListCreativeResponse} "success"
// @Router /report/creative [POST]
func (p *ReportService) ListCreativeData(ctx *gin.Context) {
	var req biz.ListReportRequest
	if err := ctx.ShouldBind(&req); err != nil {
		p.log.Error("ShouldBind err:", err)
		ResponseError(ctx, errs.ErrorArgs)
		return
	}
	if err := req.Validate(); err != nil {
		p.log.Error("Validate err:", err)
		ResponseError(ctx, err)
		return
	}

	customerIdStr := ctx.GetString(util.CustomerId)
	customerId, err := strconv.Atoi(customerIdStr)
	if err != nil {
		p.log.Error("Atoi err:", err)
		ResponseError(ctx, err)
		return
	}

	data, err := p.uc.ListCreativeData(ctx, int64(customerId), &req)
	if err != nil {
		p.log.Error("ListCreativeData err:", err)
		ResponseError(ctx, err)
		return
	}
	ResponseSuccess(ctx, data)
}
